shell Package
=============

:mod:`bootstrap` Module
-----------------------

.. automodule:: stoq.gui.shell.bootstrap
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`shell` Module
-------------------

.. automodule:: stoq.gui.shell.shell
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`shellapp` Module
----------------------

.. automodule:: stoq.gui.shell.shellapp
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`shellwindow` Module
-------------------------

.. automodule:: stoq.gui.shell.shellwindow
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`statusbar` Module
-----------------------

.. automodule:: stoq.gui.shell.statusbar
    :members:
    :undoc-members:
    :show-inheritance:

